"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getS3Object = exports.MAX_RETURN_CONTENT_LENGTH = void 0;
exports.isSmallObject = isSmallObject;
var _utils = require("../utils");
var _loaders = _interopRequireDefault(require("../transform/loaders"));
function isSmallObject(object) {
  return (object.ContentLength ?? Number.MIN_SAFE_INTEGER) < MAX_RETURN_CONTENT_LENGTH;
}
const MAX_RETURN_CONTENT_LENGTH = 5000000; // ~4.77MB
exports.MAX_RETURN_CONTENT_LENGTH = MAX_RETURN_CONTENT_LENGTH;
const getS3Object = async (fileInfo, s3, context) => {
  const {
    filename,
    options,
    extension
  } = fileInfo;
  const params = (0, _utils.getObjectParams)(filename);
  const objectHead = await s3.headObject(params).promise();
  const contentLength = objectHead.ContentLength ? objectHead.ContentLength : 0;
  const applyLoaders = options.original === undefined;
  if (applyLoaders) {
    console.log("Applying loaders...");
    for (const loader of _loaders.default) {
      try {
        const canProcess = loader.canProcess({
          context,
          s3,
          options,
          file: {
            name: filename,
            extension,
            contentLength
          }
        });
        if (!canProcess) {
          continue;
        }
        return loader.process({
          context,
          s3,
          options,
          file: {
            name: filename,
            extension,
            contentLength
          }
        });
      } catch (err) {
        console.log("ERROR WHILE PROCESSING A LOADER");
        console.log(err);
      }
    }
  } else {
    console.log("Skipping loaders.");
  }

  // If no processors handled the file request, just return the S3 object taking its size into consideration.
  let object;
  if (contentLength < MAX_RETURN_CONTENT_LENGTH) {
    object = await s3.getObject(params).promise();
  }
  return {
    object,
    params
  };
};
exports.getS3Object = getS3Object;

//# sourceMappingURL=getS3Object.js.map