"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createTransformFilePlugins = void 0;
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _s = _interopRequireDefault(require("aws-sdk/clients/s3"));
var _transformImage = require("./transformImage");
var _optimizeImage = _interopRequireDefault(require("./optimizeImage"));
var _utils = require("../utils");
var newUtils = _interopRequireWildcard(require("./utils"));
var legacyUtils = _interopRequireWildcard(require("./legacyUtils"));
var _handler = require("@webiny/handler");
const createTransformFilePlugins = () => {
  return [(0, _handler.createEvent)(async ({
    payload
  }) => {
    const {
      body
    } = payload;
    const {
      key,
      transformations
    } = body;
    try {
      const env = (0, _utils.getEnvironment)();
      const s3 = new _s.default({
        region: env.region
      });
      let optimizedImageObject;
      const utils = key.includes("/") ? newUtils : legacyUtils;
      const params = {
        initial: (0, _utils.getObjectParams)(key),
        optimized: (0, _utils.getObjectParams)(utils.getImageKey({
          key
        })),
        optimizedTransformed: (0, _utils.getObjectParams)(utils.getImageKey({
          key,
          transformations
        }))
      };

      // 1. Get optimized image.
      try {
        optimizedImageObject = await s3.getObject(params.optimized).promise();
      } catch (e) {
        // If not found, try to create it by loading the initially uploaded image.
        optimizedImageObject = await s3.getObject(params.initial).promise();
        await s3.putObject((0, _objectSpread2.default)((0, _objectSpread2.default)({}, params.optimized), {}, {
          ContentType: optimizedImageObject.ContentType,
          Body: await (0, _optimizeImage.default)(optimizedImageObject.Body, optimizedImageObject.ContentType)
        })).promise();
        optimizedImageObject = await s3.getObject(params.optimized).promise();
      }

      // 2. If no transformations requested, just exit.
      if (!transformations) {
        return {
          error: false,
          message: ""
        };
      }

      // 3. If transformations requested, apply them in save it into the bucket.
      const isAnimated = key.endsWith(".gif") || key.endsWith(".webp");
      await s3.putObject((0, _objectSpread2.default)((0, _objectSpread2.default)({}, params.optimizedTransformed), {}, {
        ContentType: optimizedImageObject.ContentType,
        Body: await (0, _transformImage.transformImage)(optimizedImageObject.Body, transformations, {
          animated: isAnimated
        })
      })).promise();
      return {
        error: false,
        message: ""
      };
    } catch (ex) {
      console.error(JSON.stringify({
        message: ex.message,
        code: ex.code,
        data: ex.data
      }));
      return {
        error: true,
        message: ex.message
      };
    }
  })];
};
exports.createTransformFilePlugins = createTransformFilePlugins;

//# sourceMappingURL=index.js.map